@@ -1,4 +1,6 @@
 #!/usr/bin/env python
+from __future__ import annotations
+
 import os
 import subprocess
 import sys
@@ -35,3 +37,8 @@ if __name__ == "__main__":
         check=True,
         capture_output=True,
     )
+    subprocess.run(
+        ["python3.11", *common_args, "-o", "py311.txt"],
+        check=True,
+        capture_output=True,
+    )
